@@ -13,12 +13,5 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import warnings
 import sys
-if sys.version_info < (3,):
-    warnings.warn(
-        "Python 2 reached the end of its life at the end of 2019.\n"
-        "Please move to Python 3 because this module will drop support "
-        "on {eod}.".format(
-            eod='31-Jan-2021'
-        ), DeprecationWarning)
+assert sys.version_info > (3,), "This module requires Python 3"
