@@ -2,7 +2,7 @@
 #
 # Exercise the opsramp module as an illustration of how to use it.
 #
-# (c) Copyright 2019 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2021 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,11 +16,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import print_function
 import os
-import sys
 import yaml
 import logging
+import argparse
 
 import opsramp.binding
 
@@ -32,15 +31,29 @@ def connect():
     return opsramp.binding.connect(url, key, secret)
 
 
+def parse_argv():
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+        '-d', '--debug',
+        action='store_true'
+    )
+    parser.add_argument(
+        'uuid',
+        type=str
+    )
+    ns = parser.parse_args()
+    return ns
+
+
 def main():
+    ns = parse_argv()
+    if ns.debug:
+        logging.basicConfig()
+        logging.getLogger().setLevel(logging.DEBUG)
+    uniqueId = ns.uuid
+
     tenant_id = os.environ['OPSRAMP_TENANT_ID']
 
-    assert len(sys.argv) == 2
-    uniqueId = sys.argv[1]
-
-    logging.basicConfig()
-    logging.getLogger().setLevel(logging.DEBUG)
-
     ormp = connect()
     tenant = ormp.tenant(tenant_id)
     group = tenant.first_response()
