@@ -2,7 +2,7 @@
 #
 # Exercise the opsramp module as an illustration of how to use it.
 #
-# (c) Copyright 2020 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2020-2021 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,10 +16,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import print_function
 import os
-import sys
 import yaml
+import logging
+import argparse
 
 import opsramp.binding
 
@@ -31,14 +31,37 @@ def connect():
     return opsramp.binding.connect(url, key, secret)
 
 
+def parse_argv():
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+        '-d', '--debug',
+        action='store_true'
+    )
+    parser.add_argument(
+        'uuid',
+        type=str
+    )
+    parser.add_argument(
+        'pattern',
+        type=str
+    )
+    ns = parser.parse_args()
+    return ns
+
+
 def main():
+    ns = parse_argv()
+    if ns.debug:
+        logging.basicConfig()
+        logging.getLogger().setLevel(logging.DEBUG)
+    resource_id = ns.uuid
+    pattern = ns.pattern
+
     tenant_id = os.environ['OPSRAMP_TENANT_ID']
 
     ormp = connect()
     tenant = ormp.tenant(tenant_id)
 
-    resource_id = sys.argv[1]
-    pattern = sys.argv[2]
     resources = tenant.resources()
     resp = resources.get_templates(resource_id, pattern)
     print(yaml.dump(resp, default_flow_style=False))
